.. option:: --output-file OUTPUT_FILE

    Path of the file to write to. Defaults to stdout.

.. option:: --exclude-deprecated True

   Option allowing the rendered output to be generated *without* deprecated
   policy information.
